about summary refs log tree commit homepage
path: root/lib/dtas/disclaimer.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/dtas/disclaimer.rb')
-rw-r--r--lib/dtas/disclaimer.rb7
1 files changed, 4 insertions, 3 deletions
diff --git a/lib/dtas/disclaimer.rb b/lib/dtas/disclaimer.rb
index 608956d..5747971 100644
--- a/lib/dtas/disclaimer.rb
+++ b/lib/dtas/disclaimer.rb
@@ -2,17 +2,18 @@
 # :enddoc:
 # Copyright (C) 2013, Eric Wong <normalperson@yhbt.net>
 # License: GPLv3 or later (https://www.gnu.org/licenses/gpl-3.0.txt)
+DTAS_PROGNAME = File.basename($0)
 DTAS_DISCLAIMER = <<EOF
 # WARNING!
 #
# Ignorant or improper use of #$0 may lead to
 # data loss, hearing loss, and damage to audio equipment.
 #
 # Please read and understand the documentation of all commands you
 # attempt to configure.
 #
# #$0 will never prevent you from doing stupid things.
 #
-# There is no warranty, the developers of #$0
+# There is no warranty, the developers of #{DTAS_PROGNAME}
 # are not responsible for your actions.
 EOF
@@ -2,17 +2,18 @@
 # WARNING!
 #
-# Ignorant or improper use of #$0 may lead to
+# Ignorant or improper use of #{DTAS_PROGNAME} may lead to
 # data loss, hearing loss, and damage to audio equipment.
 #
@@ -2,17 +2,18 @@
 # attempt to configure.
 #
-# #$0 will never prevent you from doing stupid things.
+# #{DTAS_PROGNAME} will never prevent you from doing stupid things.
 #